# py_af_colours
The py_af_colours package aims to maintain the accessibility of graph outputs generated in Python across the Analysis Function by simplifying the process by which users can access the standardised colour palettes. This package aids ease-of-use by reducing manual steps involved with searching for and accessing the palettes.

This package sits alongside an R equivalent: https://github.com/best-practice-and-impact/afcolours

For full documentation on py_af_colours, please go to: https://best-practice-and-impact.github.io/py-af-colours/
